@@ -9,6 +9,7 @@ import os
 import argparse
 import mysql.connector
 import yaml
+from tqdm import tqdm
 
 #millores a fer:
 # apendre a anexar al excel per poder fer algunes funcions actualment commentades
@@ -98,7 +99,7 @@ def InfoCopies(url, cookie, sid):#6 issue. A vegades dona error sense motiu apar
 		f.write(str(response))
 		f.close()
 		print(response)
-		return("{'data': {'device_list': , 'total': 0}, 'success': False}")
+		return({'data': {'device_list': [], 'total': 0}, 'success': False})
 
 #Recull totes les dades de tots els NAS
 #El paramatre workbook es per si la opció del excel es activa escriu dades el excel si no es pot connectar amb la maquina
@@ -107,7 +108,6 @@ def recoleccioDades(workbook):
 	global current_transaction
 	global fitxer
 	Backups = []
-	num_dispositius = len(taulabd)
 	for x in taulabd:
 		#aconseguir un apartat de la url (aut.cgi o entry.cgi)
 		cookie = x[4]
@@ -184,7 +184,6 @@ def tamanyRestant(i):
 		path= str(query['data']['SYNO.API.Auth']['path'])
 		url = taulabd[i][3]+"webapi/"+path
 	except Exception as e:
-		print("Error en la query")
 		now = datetime.datetime.now()
 		date_string = now.strftime('%Y-%m-%d--%H-%M-%S-Query')
 		a = open("errorLogs/"+date_string+".txt",'w')
@@ -255,11 +254,29 @@ def escriptorExcel(nom_dispositiu, status, temps_finalitzacio, tamany_transferen
 		ws = workbook.create_sheet(nom_nas)
 		escriureDades(nom_dispositiu, ws, status, temps_finalitzacio, tamany_transferencia, y, z, nom_nas, tamanyLliure)
 
-#Prepara la fulla principal del excel en cas de que no existis abans
+#Complementa a prepExcel pr borrar la primera fulla perque aixis no hi hagi dades d'altres execucions
+#Es crida per cada fila i se li passa la fulla i la fila actual
+def borrar(sheet, row):
+	for cell in row:
+		if cell.value == None:
+			return
+		sheet.delete_rows(row[0].row, 1)
+
+#Prepara el excel en cas de que no existis abans (borrant dades ateriors i posant la capçalera)
 #L'únic parametre es el document d'excel
-#No retorna res. S'hauria de fer que tambe dones format condicional entre altres
+#No retorna res.
 def prepExcel(workbook):
+	if args.quiet:
+		print("Preparant excel")
+	for sheet in workbook:
+		if sheet.title != "Sheet":
+			workbook.remove(sheet)
+			
 	wsdefault = workbook['Sheet']
+	
+	for row in wsdefault:
+		borrar(wsdefault,row)			
+
 	wsdefault.cell(row=1, column=1, value="Nom NAS")
 	wsdefault.cell(row=1, column=2, value="Nom Dispositiu")
 	wsdefault.cell(row=1, column=3, value="Data")
@@ -267,6 +284,7 @@ def prepExcel(workbook):
 	wsdefault.cell(row=1, column=5, value="Status")
 	wsdefault.cell(row=1, column=6, value="Tamany Lliure GB")
 
+
 #Acces a la base de dades i recoleccio de la informacio
 #Els parametres son les credencials i la ip/host de la base de dades
 #Retorna una llista igual a la base de dades
@@ -279,7 +297,8 @@ def bd(servidor, usuari, contrassenya):
     	    database="synology"
     	    )
 		mycursor = mydb.cursor(buffered=True)
-		print("Access BDD correcte")
+		if args.quiet:
+			print("Access BDD correcte")
 	except:
 		try:        
 			mydb =mysql.connector.connect(
@@ -334,7 +353,7 @@ parser = argparse.ArgumentParser(description='Una API per a recullir invormacio
 parser.add_argument('-e', '--excel', help='Guardar la informacio a un excel, per defecte esta desactivat', action="store_true")
 parser.add_argument('-q', '--quiet', help='Nomes mostra els errors i el missatge de acabada per pantalla.', action="store_false")
 parser.add_argument('-f', '--file', help='Especificar el fitxer de excel a on guardar. Per defecte es revisio_copies_seguretat_synology_vs1.xlsx', default="revisio_copies_seguretat_synology_vs1.xlsx", metavar="RUTA")
-parser.add_argument('-v', '--versio', help='Mostra la versio', action='version', version='Synology_API-NPP vs1.6.5')
+parser.add_argument('-v', '--versio', help='Mostra la versio', action='version', version='Synology_API-NPP vs1.6.8')
 args = parser.parse_args()
 
 current_transaction = 2
@@ -368,12 +387,12 @@ if exists(fitxer) == False:
 	workbook = Workbook()
 	prepExcel(workbook)
 	workbook.save(fitxer)
-	
-workbook = load_workbook(filename = fitxer)
-if args.excel:
-	for sheet in workbook:
-		if sheet.title != "Sheet":
-			workbook.remove(sheet)
+elif args.excel:
+	workbook = load_workbook(filename = fitxer)
+	prepExcel(workbook)
+else:
+	workbook = load_workbook(filename = fitxer)
+
 
 llistaTransf = []
 llistadispCopia = []
@@ -388,7 +407,7 @@ num_nas = len(dadesCopiesTotes)
 # current_transaction es cada transaccio (es reseteja cada execucio)
 nas = 0
 nom_dispositiu=""
-while nas < num_nas:
+for nas in tqdm (range(num_nas), desc="Processar Dades", ncols=100, disable=args.quiet):
 	nom_nas = taulabd[nas][0]
 	id_pandora = taulabd[nas][5]
 	num_copies = int(dadesCopiesTotes[nas]['data']['total'])
@@ -400,25 +419,16 @@ while nas < num_nas:
 			num_transferencies = len(dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'])
 
 			y=0
-			while y < num_transferencies:
+			for y in tqdm (range (num_transferencies), desc=nom_nas +" | "+ dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'][y]['device_name'], ncols=75, disable=not(args.quiet)):
 				nom_dispositiu = dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'][y]['device_name']
 				status = statusConvertor(dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'][y]['status'])
 				tamany_transferencia = dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'][y]['transfered_bytes']
 				temps_finalitzacio = dadesCopiesTotes[nas]['data']['device_list'][x]['transfer_list'][y]['time_end']
-				if args.quiet:
-					if y==0:
-						print()
-						print(nom_dispositiu)
-						print("[", end="")
-					if status == "Correcte":
-						print("#", end="")
-					elif args.quiet:
-						print("X", end="")
 
 				file_time = datetime.datetime.fromtimestamp(temps_finalitzacio)
 				dataF=file_time.strftime('%Y-%m-%d')
 				if y+1 < num_transferencies:
-					u=1
+					u=1 #no se que fa
 				else:
 					llistaTransf.append({"data":dataF, "status":status, "tamany_transferenciaMB":(tamany_transferencia/1024)/1024})
 				if args.excel:
@@ -432,11 +442,6 @@ while nas < num_nas:
 						f.write("Error de permisos en obrir el Excel (Pot ser que el excel estigui obert?)")
 						f.close()
 						print("Error de permisos")
-
-				y += 1
-			if args.quiet:
-				print("]", end="")
-				print()
 			z += 1
 		llistadispCopia.append({"nomDispositiu":nom_dispositiu, "Transferencies":llistaTransf})
 		nom_dispositiu = ""
